Indexes
==============

TextIndex
^^^^^^^^^^^

**TextIndex** is a wrapper around `Spotify's AnnoyIndex <https://github.com/spotify/annoy>`_

.. autoclass:: datawords.indexes.TextIndex
               :members:



SQLiteIndex
^^^^^^^^^^^

**SQLiteIndex** index and search documents using SQLite. Check `sqlite fts search queries <https://saraswatmks.github.io/2020/04/sqlite-fts-search-queries.html>`_


.. autoclass:: datawords.indexes.LiteDoc
               :members:


.. autoclass:: datawords.indexes.SQLiteIndex
               :members:

